/*******************************************************************************
*                                                                              *
*   NetBurner MOD5270 General Purpose Input/Output Header File                 *
*   gpio5270.h                                                                 *
*                                                                              *
*******************************************************************************/


////////////////////////////////////////////////////////////////////////////////
// GPIO Pin Assignment Register Definitions. All signals are referenced to their
// primary functions. Writing the complement of each of the following defined
// values associated with a signal in the register will configure the
// corresponding pin for GPIO.
//

//
// For use with data port pin assignment register: sim.gpio.par_ad.
//
#define GPIO_PAR_DATA       (   0x01 )   // Bit       0 - P Data High/Low [15:0]

//
// For use with DMA timer port pin assignment register: sim.gpio.par_timer.
//
#define GPIO_PAR_DTOUT0     ( 0x0003 )   // Bit  1 -  0 - DMA Timer Output 0
#define GPIO_PAR_DTOUT1     ( 0x000C )   // Bit  3 -  2 - DMA Timer Output 1
#define GPIO_PAR_DTOUT3     ( 0x00C0 )   // Bit  7 -  6 - DMA Timer Output 3
#define GPIO_PAR_TIN0       ( 0x0300 )   // Bit  9 -  8 - DMA Timer Input 0
#define GPIO_PAR_TIN1       ( 0x0C00 )   // Bit 11 - 10 - DMA Timer Input 1
#define GPIO_PAR_TIN2       ( 0x3000 )   // Bit 13 - 12 - DMA Timer Input 2

//
// For use with I2C port pin assignment register: sim.gpio.par_feci2c.
//
#define GPIO_PAR_SDA        (   0x03 )   // Bit  1 -  0 - I2C Serial Data
#define GPIO_PAR_SCL        (   0x0C )   // Bit  3 -  2 - I2C Serial Clock

//
// For use with QSPI port pin asssignment register: sim.gpio.par_qspi.
//
#define GPIO_PAR_SPICLK     (   0x03 )   // Bit  1 -  0 - SPI Clock
#define GPIO_PAR_SPIDOUT    (   0x04 )   // Bit       2 - SPI Data Out
#define GPIO_PAR_SPIDIN     (   0x18 )   // Bit  4 -  3 - SPI Data In
#define GPIO_PAR_SPICS0     (   0x20 )   // Bit       5 - SPI Chip Select 0
#define GPIO_PAR_SPICS1     (   0xC0 )   // Bit  7 -  6 - SPI Chip Select 1

//
// For use with UART port pin assignment register: sim.gpio.par_uart.
//
#define GPIO_PAR_URT0RTS    ( 0x0001 )   // Bit       0 - UART 0 - Ready to Send
#define GPIO_PAR_URT0CTS    ( 0x0002 )   // Bit       1 - UART 0 - Clear to Send
#define GPIO_PAR_UTXD0      ( 0x0004 )   // Bit       2 - UART 0 - Transmit
#define GPIO_PAR_URXD0      ( 0x0008 )   // Bit       3 - UART 0 - Receive
#define GPIO_PAR_URT1RTS    ( 0x0030 )   // Bit  5 -  4 - UART 1 - Ready to Send
#define GPIO_PAR_URT1CTS    ( 0x00C0 )   // Bit  7 -  6 - UART 1 - Clear to Send
#define GPIO_PAR_UTXD1      ( 0x0300 )   // Bit  9 -  8 - UART 1 - Transmit
#define GPIO_PAR_URXD1      ( 0x0C00 )   // Bit 11 - 10 - UART 1 - Receive
#define GPIO_PAR_UART2TX    ( 0x1000 )   // Bit      12 - UART 2 - Transmit
#define GPIO_PAR_UART2RX    ( 0x2000 )   // Bit      13 - UART 2 - Receive

//
// For use with chip select pin assignment register: sim.gpio.par_cs.
//
#define GPIO_PAR_CS1        (   0x02 )   // Bit       1 - Chip Select #1
#define GPIO_PAR_CS2        (   0x04 )   // Bit       2 - Chip Select #2
#define GPIO_PAR_CS3        (   0x08 )   // Bit       3 - Chip Select #3


////////////////////////////////////////////////////////////////////////////////
// GPIO Port Data Direction Register, Port Output Data Register, Port Pin Data/
// Set Data Register, and Port Clear Output Data Register Definitions. The
// following defined values are only for use on corresponding pins that are
// configured for GPIO.
//
// Port Data Direction Register (PDDR)
// Write: 0 = Input, 1 = Output
// Read: The current values in the register
//
// Port Output Data Register (PODR)
// Write: 0 = Low, 1 = High
// Read: The current values in the register (not the port pin values)
//
// Port Pin Data/Set Data Register (PPDSDR)
// Write: 0 = No Effect, 1 = High (for corresponding bits in PODR)
// Read: The current state of the pins
//
// Port Clear Output Data Register (PCLRR)
// Write: 0 = Low (for corresponding bits in PODR), 1 = No Effect
// Read: Always return zeros
//

//
// For use with sim.gpio.pddr_datal, sim.gpio.podr_datal, sim.gpio.ppdsdr_datal,
// and sim.gpio.pclrr_datal.
//
#define GPIO_PIN_DATAL0     (   0x01 )   // Bit 0 - P Data Low   0
#define GPIO_PIN_DATAL1     (   0x02 )   // Bit 1 - P Data Low   1
#define GPIO_PIN_DATAL2     (   0x04 )   // Bit 2 - P Data Low   2
#define GPIO_PIN_DATAL3     (   0x08 )   // Bit 3 - P Data Low   3
#define GPIO_PIN_DATAL4     (   0x10 )   // Bit 4 - P Data Low   4
#define GPIO_PIN_DATAL5     (   0x20 )   // Bit 5 - P Data Low   5
#define GPIO_PIN_DATAL6     (   0x40 )   // Bit 6 - P Data Low   6
#define GPIO_PIN_DATAL7     (   0x80 )   // Bit 7 - P Data Low   7

//
// For use with sim.gpio.pddr_datah, sim.gpio.podr_datah, sim.gpio.ppdsdr_datah,
// and sim.gpio.pclrr_datah.
//
#define GPIO_PIN_DATAH8     (   0x01 )   // Bit 0 - P Data High  8
#define GPIO_PIN_DATAH9     (   0x02 )   // Bit 1 - P Data High  9
#define GPIO_PIN_DATAH10    (   0x04 )   // Bit 2 - P Data High 10
#define GPIO_PIN_DATAH11    (   0x08 )   // Bit 3 - P Data High 11
#define GPIO_PIN_DATAH12    (   0x10 )   // Bit 4 - P Data High 12
#define GPIO_PIN_DATAH13    (   0x20 )   // Bit 5 - P Data High 13
#define GPIO_PIN_DATAH14    (   0x40 )   // Bit 6 - P Data High 14
#define GPIO_PIN_DATAH15    (   0x80 )   // Bit 7 - P Data High 15

//
// For use with sim.gpio.pddr_timer, sim.gpio.podr_timer, sim.gpio.ppdsdr_timer,
// and sim.gpio.pclrr_timer.
//
#define GPIO_PIN_DTOUT0     (   0x01 )   // Bit 0 - DMA Timer Output 0
#define GPIO_PIN_DTOUT1     (   0x04 )   // Bit 2 - DMA Timer Output 1
#define GPIO_PIN_DTOUT3     (   0x40 )   // Bit 6 - DMA Timer Output 3
#define GPIO_PIN_TIN0       (   0x02 )   // Bit 1 - DMA Timer Input  0
#define GPIO_PIN_TIN1       (   0x08 )   // Bit 3 - DMA Timer Input  1
#define GPIO_PIN_TIN2       (   0x20 )   // Bit 5 - DMA Timer Input  2

//
// For use with sim.gpio.pddr_feci2c, sim.gpio.podr_feci2c,
// sim.gpio.ppdsdr_feci2c, and sim.gpio.pclrr_feci2c.
//
#define GPIO_PIN_SDA        (   0x01 )   // Bit 0 - I2C Serial Data
#define GPIO_PIN_SCL        (   0x02 )   // Bit 1 - I2C Serial Clock

//
// For use with sim.gpio.pddr_qspi, sim.gpio.podr_qspi, sim.gpio.ppdsdr_qspi,
// and sim.gpio.pclrr_qspi.
//
#define GPIO_PIN_SPICLK     (   0x04 )   // Bit 2 - SPI Clock
#define GPIO_PIN_SPIDOUT    (   0x01 )   // Bit 0 - SPI Data Out
#define GPIO_PIN_SPIDIN     (   0x02 )   // Bit 1 - SPI Data In
#define GPIO_PIN_SPICS0     (   0x08 )   // Bit 3 - SPI Chip Select 0
#define GPIO_PIN_SPICS1     (   0x10 )   // Bit 4 - SPI Chip Select 1

//
// For use with sim.gpio.pddr_uartl, sim.gpio.podr_uartl, sim.gpio.ppdsdr_uartl,
// and sim.gpio.pclrr_uartl.
//
#define GPIO_PIN_URT0RTS    (   0x04 )   // Bit 2 - UART 0 - Ready to Send
#define GPIO_PIN_URT0CTS    (   0x08 )   // Bit 3 - UART 0 - Clear to Send
#define GPIO_PIN_UTXD0      (   0x02 )   // Bit 1 - UART 0 - Transmit
#define GPIO_PIN_URXD0      (   0x01 )   // Bit 0 - UART 0 - Receive
#define GPIO_PIN_URT1RTS    (   0x40 )   // Bit 6 - UART 1 - Ready to Send
#define GPIO_PIN_URT1CTS    (   0x80 )   // Bit 7 - UART 1 - Clear to Send
#define GPIO_PIN_UTXD1      (   0x20 )   // Bit 5 - UART 1 - Transmit
#define GPIO_PIN_URXD1      (   0x10 )   // Bit 4 - UART 1 - Receive

//
// For use with sim.gpio.pddr_uarth, sim.gpio.podr_uarth, sim.gpio.ppdsdr_uarth,
// and sim.gpio.pclrr_uarth.
//
#define GPIO_PIN_UART2TX    (   0x02 )   // Bit 1 - UART 2 - Transmit
#define GPIO_PIN_UART2RX    (   0x01 )   // Bit 0 - UART 2 - Receive

//
// For use with sim.gpio.pddr_cs, sim.gpio.podr_cs, sim.gpio.ppdsdr_cs, and
// sim.gpio.pclrr_cs.
//
#define GPIO_PIN_CS1        (   0x02 )   // Bit 1 - Chip Select #1
#define GPIO_PIN_CS2        (   0x04 )   // Bit 2 - Chip Select #2
#define GPIO_PIN_CS3        (   0x08 )   // Bit 3 - Chip Select #3

//
// For use with sim.eport.epddr (EPORT Data Direction Register), sim.eport.epdr
// (EPORT Data Register - similar to PODR), and sim.eport.eppdr (EPORT Pin Data
// Register - similar to PPDSDR).
//
#define GPIO_PIN_IRQ1       (   0x02 )   // Bit 1 - External Interrupt #1
#define GPIO_PIN_IRQ3       (   0x08 )   // Bit 3 - External Interrupt #3
#define GPIO_PIN_IRQ5       (   0x20 )   // Bit 5 - External Interrupt #5
#define GPIO_PIN_IRQ7       (   0x80 )   // Bit 7 - External Interrupt #7
